==> zio-aws-batch_2.13-5.17.129.1-sources.jar: zio/aws/batch/model/RetryStrategy.scala <==
package zio.aws.batch.model
import zio.aws.batch.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class RetryStrategy(
    attempts: Option[Integer] = None,
    evaluateOnExit: Option[Iterable[zio.aws.batch.model.EvaluateOnExit]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.batch.model.RetryStrategy = {
    import RetryStrategy.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.batch.model.RetryStrategy
      .builder()
      .optionallyWith(
        attempts.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.attempts)
      .optionallyWith(
        evaluateOnExit.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.evaluateOnExit)
      .build()
  }
  def asReadOnly: zio.aws.batch.model.RetryStrategy.ReadOnly =
    zio.aws.batch.model.RetryStrategy.wrap(buildAwsValue())
}
object RetryStrategy {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.batch.model.RetryStrategy
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.batch.model.RetryStrategy =
      zio.aws.batch.model.RetryStrategy(
        attempts.map(value => value),
        evaluateOnExit.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def attempts: Option[Integer]
    def evaluateOnExit
        : Option[List[zio.aws.batch.model.EvaluateOnExit.ReadOnly]]
    def getAttempts: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("attempts", attempts)
    def getEvaluateOnExit: ZIO[Any, AwsError, List[
      zio.aws.batch.model.EvaluateOnExit.ReadOnly
    ]] = AwsError.unwrapOptionField("evaluateOnExit", evaluateOnExit)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.batch.model.RetryStrategy
  ) extends zio.aws.batch.model.RetryStrategy.ReadOnly {
    override val attempts: Option[Integer] = scala
      .Option(impl.attempts())
      .map(value => zio.aws.batch.model.primitives.Integer(value))
    override val evaluateOnExit
        : Option[List[zio.aws.batch.model.EvaluateOnExit.ReadOnly]] = scala
      .Option(impl.evaluateOnExit())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.batch.model.EvaluateOnExit.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.batch.model.RetryStrategy
  ): zio.aws.batch.model.RetryStrategy.ReadOnly = new Wrapper(impl)
}

==> zio-aws-batch_2.13-5.17.146.2-sources.jar: zio/aws/batch/model/RetryStrategy.scala <==
package zio.aws.batch.model
import zio.aws.batch.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class RetryStrategy(
    attempts: Option[Integer] = None,
    evaluateOnExit: Option[Iterable[zio.aws.batch.model.EvaluateOnExit]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.batch.model.RetryStrategy = {
    import RetryStrategy.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.batch.model.RetryStrategy
      .builder()
      .optionallyWith(attempts.map(value => value: java.lang.Integer))(
        _.attempts
      )
      .optionallyWith(
        evaluateOnExit.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.evaluateOnExit)
      .build()
  }
  def asReadOnly: zio.aws.batch.model.RetryStrategy.ReadOnly =
    zio.aws.batch.model.RetryStrategy.wrap(buildAwsValue())
}
object RetryStrategy {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.batch.model.RetryStrategy
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.batch.model.RetryStrategy =
      zio.aws.batch.model.RetryStrategy(
        attempts.map(value => value),
        evaluateOnExit.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def attempts: Option[Integer]
    def evaluateOnExit
        : Option[List[zio.aws.batch.model.EvaluateOnExit.ReadOnly]]
    def getAttempts: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("attempts", attempts)
    def getEvaluateOnExit: ZIO[Any, AwsError, List[
      zio.aws.batch.model.EvaluateOnExit.ReadOnly
    ]] = AwsError.unwrapOptionField("evaluateOnExit", evaluateOnExit)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.batch.model.RetryStrategy
  ) extends zio.aws.batch.model.RetryStrategy.ReadOnly {
    override val attempts: Option[Integer] =
      scala.Option(impl.attempts()).map(value => value: Integer)
    override val evaluateOnExit
        : Option[List[zio.aws.batch.model.EvaluateOnExit.ReadOnly]] = scala
      .Option(impl.evaluateOnExit())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.batch.model.EvaluateOnExit.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.batch.model.RetryStrategy
  ): zio.aws.batch.model.RetryStrategy.ReadOnly = new Wrapper(impl)
}
